require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xwinrm',
  dscmeta_resource_friendly_name: 'xWinRM',
  dscmeta_resource_name: 'xWinRM',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xwinrm',
  dscmeta_module_version: '1.0.14',
  docs: 'The DSC xWinRM resource type.
         Automatically generated from version 1.0.14',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_maxenvelopesizekb: {
      type: 'Optional[String]',
      desc: 'Set the MaxEnvelopeSizekb value',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_httpscertthumpprint: {
      type: 'Optional[String]',
      desc: 'Enter value of HTTPS certificate thumprint',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_certificate: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable certificate auth for the WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxproviderrequests: {
      type: 'Optional[String]',
      desc: 'Set the MaxProviderRequests value',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_certificate: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable certificate auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_credssp: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable credssp auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_httpport: {
      type: 'Optional[String]',
      desc: 'Set the HTTP WinRM port',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_allowunencrypted: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable unencrypted WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_maxbatchitems: {
      type: 'Optional[String]',
      desc: 'Set the MaxBatchItems value',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_httpsport: {
      type: 'Optional[String]',
      desc: 'Set the HTTPS WinRM port',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_basic: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable basic auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_kerberos: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable kerberos auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_protocol: {
      type: "Enum['HTTP', 'HTTPS']",
      desc: 'Listener protocol',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_kerberos: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable kerberos auth for the WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_basic: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable basic auth for the WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_digest: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable digest auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_negotiate: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable negotiate auth for the WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_client_allowunencrypted: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable unencrypted WinRM client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxmemorypershellmb: {
      type: 'Optional[String]',
      desc: 'Set the MaxMemoryPerShellMB value',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_credssp: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable credssp auth for the WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_service_negotiate: {
      type: "Optional[Enum['true', 'false']]",
      desc: 'Enable or disable negotiate auth for the WinRM service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxtimeoutms: {
      type: 'Optional[String]',
      desc: 'Set the MaxTimeoutms value',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restartservice: {
      type: 'Optional[Boolean]',
      desc: 'Restart the WinRM Service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
